<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="utf-8" />
  <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap.min.css">
</head>

<body>
    <div class="container">
        <header class="page-header">
        </header>
        <div class="row">
            {% block base-content %}{% endblock %}
        </div>
    </div>
</body>
</html>
