{% extends "pgallery/base_photos.html" %}
{% load i18n %}

{% block content %}
    <article>
        <h1>{% trans "Tag" %}: {{ tag }}</h1>
        {% include "pgallery/thumbnail_list.html" %}
    </article>
{% endblock %}

