{% load i18n %}

<ul class="thumbnails">
    {% for photo in photo_list %}
    <li>
        <a class="thumbnail" title="{{ photo.title }}" href="{{ photo.get_absolute_url }}">
            <img src="{{ photo.image.url }}" alt="{{ photo.title }}" width="200" height="200" />
            <span class="description">{{ photo.title }}</span>
        </a>
    </li>
    {% endfor %}
</ul>
