{% extends "pgallery/base_photos.html" %}
{% load i18n %}

{% block content %}
    {% for gallery in gallery_list %}
        <article>
            <h1><a href="{{ gallery.get_absolute_url }}">{{ gallery.title }}</a></h1>
            {% include "pgallery/thumbnail_list.html" with photo_list=gallery.get_teaser_photos %}

            <footer>
                {% trans "added on" %} {{ gallery.shot_date|date:"DATE_FORMAT" }}
            </footer>
        </article>
    {% empty %}
        <p>{% trans "There aren't any galleries." %}</p>
    {% endfor %}
{% endblock %}

