# Generated by Django 2.2.12 on 2020-04-12 11:11

import django.contrib.postgres.fields.hstore
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("pgallery", "0004_auto_20160416_2351"),
    ]

    operations = [
        migrations.AlterField(
            model_name="photo",
            name="exif",
            field=django.contrib.postgres.fields.hstore.HStoreField(
                db_index=True, default=dict, editable=False
            ),
        ),
    ]
